@@ -29,7 +29,7 @@
 #' the shape of this curve.
 #' 4. You can use/merge/transform/adapt any of these functions.
 #' @export
-#' @examples {
+#' @examples \dontrun{
 #' data(net)
 #' MOTO_E25_500 <- age_moto(x = net$ldv, name = "M_E25_500", k = 0.4)
 #' plot(MOTO_E25_500)
@@ -53,13 +53,10 @@ age_moto <- function (x,
   #check agemax
   if(agemax < 1) stop("Agemax should be bigger than 1")
 
-  if (missing(x) | is.null(x)) {
-    stop (print("Missing vehicles"))
-  }
-  # bystreet = TRUE
+   # bystreet = TRUE
   if (bystreet == T){
     if(length(x) != length(a)){
-      stop(print("Lengths of veh and age must be the same"))
+      stop("Lengths of veh and a must be the same")
     }
     d <- suca <- list()
     for (i in seq_along(x)) {
