@@ -10,7 +10,7 @@
 #' @return data-frames of expanded traffic or sf.
 #' @importFrom sf st_sf st_as_sf
 #' @export
-#' @examples {
+#' @examples \dontrun{
 #' # Do not run
 #' data(net)
 #' data(pc_profile)
@@ -22,10 +22,11 @@
 temp_fact <- function(q, pro, net) {
   if (missing(q) | is.null(q)) {
     stop("No traffic data")
-  } else {
-   df <- Vehicles(as.data.frame(as.matrix(q) %*% matrix(unlist(pro), nrow=1)))
   }
-  if(!missing(net)){
+
+   df <- Vehicles(as.data.frame(as.matrix(q) %*% matrix(unlist(pro), nrow=1)))
+
+   if(!missing(net)){
   netsf <- sf::st_as_sf(net)
   speed <- sf::st_sf(df, geometry = netsf$geometry)
   return(speed)
